@@ -21,8 +21,7 @@
 
 import os
 from argparse import ArgumentParser
-from itertools import chain
-from random import choice
+from random import choice, shuffle
 from datetime import datetime, timedelta
 
 import yaml
@@ -126,7 +125,10 @@ class ReviewAssigner:
                 query_data={"assignee_id": user.id},
             )
         except GitlabHttpError:
-            print(f"ERROR: no permission to assign a reviewer to {merge_request.title}")
+            print(
+                f"ERROR: no permission to assign a reviewer to {merge_request.title}"
+                f" ({merge_request.web_url})"
+            )
             return
 
         self.review_states.loc[len(self.review_states)] = (
@@ -137,27 +139,35 @@ class ReviewAssigner:
         print(f"{user.name} has been assigned to {merge_request.title}")
 
     def all_reviews_to_do(self):
-        mr_with_to_review_tag = self.cnx.mergerequests.list(
+        merge_requests = self.cnx.mergerequests.list(
             labels=TO_REVIEW_LABEL,
             state="opened",
             wip="no",
             scope="all",
             assignee_id="None",
-            as_list=False,
             all=True,
         )
 
-        mr_with_no_tags = self.cnx.mergerequests.list(
-            labels="None",
-            state="opened",
-            wip="no",
-            scope="all",
-            assignee_id="None",
-            as_list=False,
-            all=True,
+        merge_requests.extend(
+            self.cnx.mergerequests.list(
+                labels="None",
+                state="opened",
+                wip="no",
+                scope="all",
+                assignee_id="None",
+                all=True,
+            )
         )
 
-        for merge_request in chain(mr_with_to_review_tag, mr_with_no_tags):
+        shuffle(merge_requests)
+
+        for merge_request in merge_requests:
+            if merge_request.work_in_progress:
+                # double check that the MR is not WIP.
+                # it seems that filtering in the search parameters is not enough
+                # XXX is it a Gitlab bug ?
+                continue
+
             project = self.cnx.projects.get(merge_request.project_id)
             if CLIENT_PROJECT_TAG in project.tag_list:
                 # it's a client project. Let's assume that someone will take
